@@ -43,11 +43,11 @@ var searchData=
   ['graphiclocation_2eidl',['GraphicLocation.idl',['../GraphicLocation_8idl.html',1,'']]],
   ['graphicobject_2eidl',['GraphicObject.idl',['../GraphicObject_8idl.html',1,'']]],
   ['graphicobjectcount_2eidl',['GraphicObjectCount.idl',['../GraphicObjectCount_8idl.html',1,'']]],
-  ['graphicobjectresolver_2eidl',['GraphicObjectResolver.idl',['../GraphicObjectResolver_8idl.html',1,'']]],
   ['graphicobjectshape_2eidl',['GraphicObjectShape.idl',['../drawing_2GraphicObjectShape_8idl.html',1,'(Global Namespace)'],['../presentation_2GraphicObjectShape_8idl.html',1,'(Global Namespace)']]],
   ['graphicprovider_2eidl',['GraphicProvider.idl',['../GraphicProvider_8idl.html',1,'']]],
   ['graphicrasterizer_2eidl',['GraphicRasterizer.idl',['../GraphicRasterizer_8idl.html',1,'']]],
   ['graphicrenderervcl_2eidl',['GraphicRendererVCL.idl',['../GraphicRendererVCL_8idl.html',1,'']]],
+  ['graphicstoragehandler_2eidl',['GraphicStorageHandler.idl',['../GraphicStorageHandler_8idl.html',1,'']]],
   ['graphictype_2eidl',['GraphicType.idl',['../GraphicType_8idl.html',1,'']]],
   ['gridcolumn_2eidl',['GridColumn.idl',['../GridColumn_8idl.html',1,'']]],
   ['gridcolumnevent_2eidl',['GridColumnEvent.idl',['../GridColumnEvent_8idl.html',1,'']]],
